<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Shpjere te Hedhurina</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Hape</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Hiqe nga paneli</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Detyro Dalje</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Mbylli Krejt</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Hape</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Hiqe nga paneli</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Detyro Dalje</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Mbylli Krejt</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 kartela</translation>
    </message>
</context>
</TS>